/* 
  Agent.h

  Barry McMullin <mcmullin@eeng.dcu.ie>
  11-OCT-1996
*/

#import <objectbase/SwarmObject.h>
#import <simtools.h>


@interface Agent: SwarmObject

-saveTo: (OutFile *) file;
-loadFrom: (InFile *) file;

@end
